==> rill-0.0.498.tgz: package/server/hijackBrowser/index.js <==
/** Rill v0.0.498 https://www.npmjs.com/package/rill License: MIT*/
var createRequest, event, expect, handleChange, handleClick, hijack, ref;

event = require("component-event");

expect = require("../util/expect");

createRequest = function() {};

hijack = module.exports = {

  /*
  	 * Listen to all url change events on a dom element and trigger the server callback.
  	#
  	 * @param {DOMNode} element
  	 * @api private
   */
  listen: function(element) {
    if (element == null) {
      element = window;
    }
    event.bind(element, "DOMContentLoaded", handleChange);
    event.bind(element, "popstate", handleChange);
    event.bind(element, "submit", handleClick);
    event.bind(element, "click", handleClick);
    return hijack;
  },

  /*
  	 * Add a handler to listen to url changes.
  	#
  	 * @param {Function} handler
  	 * @api private
   */
  createServer: function(handler) {
    createRequest = handler;
    return hijack;
  },

  /*
  	 * Trigger the registered handler to navigate to a given url.
  	#
  	 * @param {String} url
  	 * @param {Object} options
  	 * @api private
   */
  goTo: function(url, arg) {
    var body, headers, method, ref, req, title;
    ref = arg != null ? arg : {}, method = ref.method, headers = ref.headers, body = ref.body, title = ref.title;
    if (title == null) {
      title = "";
    }
    req = {
      url: url,
      body: body,
      method: method != null ? method : "GET",
      headers: headers != null ? headers : {}
    };
    return createRequest(req).then(function(arg1) {
      var redirected;
      redirected = arg1.redirected;
      if (!redirected) {
        window.history.pushState(req, title, url);
      }
    });
  }
};

ref = require("./handlers"), handleClick = ref.handleClick, handleChange = ref.handleChange;

==> rill-0.0.499.tgz: package/server/hijackBrowser/index.js <==
/** Rill v0.0.499 https://www.npmjs.com/package/rill License: MIT*/
var createRequest, event, handleChange, handleClick, hijack, ref;

event = require("component-event");

createRequest = function() {};

hijack = module.exports = {

  /*
  	 * Listen to all url change events on a dom element and trigger the server callback.
  	#
  	 * @param {DOMNode} element
  	 * @api private
   */
  listen: function(element) {
    if (element == null) {
      element = window;
    }
    event.bind(element, "DOMContentLoaded", handleChange);
    event.bind(element, "popstate", handleChange);
    event.bind(element, "submit", handleClick);
    event.bind(element, "click", handleClick);
    return hijack;
  },

  /*
  	 * Add a handler to listen to url changes.
  	#
  	 * @param {Function} handler
  	 * @api private
   */
  createServer: function(handler) {
    createRequest = handler;
    return hijack;
  },

  /*
  	 * Trigger the registered handler to navigate to a given url.
  	#
  	 * @param {String} url
  	 * @param {Object} options
  	 * @api private
   */
  goTo: function(url, arg) {
    var headers, method, ref, replaceState, req, title;
    ref = arg != null ? arg : {}, method = ref.method, headers = ref.headers, title = ref.title, replaceState = ref.replaceState;
    if (title == null) {
      title = "";
    }
    req = {
      url: url,
      method: method != null ? method : "GET",
      headers: headers != null ? headers : {}
    };
    window.history[Boolean(replaceState) ? "replaceState" : "pushState"](req, title, url);
    createRequest(req);
  }
};

ref = require("./handlers"), handleClick = ref.handleClick, handleChange = ref.handleChange;
